@@ -1,4 +1,4 @@
-/* 
+/*
  * kissd - KiSS PC-Link Daemon
  *
  * Copyright (C) 2005 Stelian Pop <stelian@popies.net>
@@ -31,7 +31,7 @@ extern char videopath[];
 extern char picturepath[];
 extern char kmlurl[];
 
-#define KISSD_VERSION "version 0.3, Feb 11, 2005"
+#define KISSD_VERSION "version 0.5, Apr 15, 2005"
 
 void handle_request(int sock);
 void handle_kmlrequest(int sock);
@@ -45,4 +45,4 @@ void clean_pathname(char *path);
 			fprintf(stderr, format "\n", args);	\
 	} while(0)
 
-#define max(a, b) ((a) > (b)) ? (a) : (b)
+#define max(a, b) (((a) > (b)) ? (a) : (b))
